---
title: <span class="badge builder"></span> BaseMovingAverageModelSettings
---
# <span class="badge builder"></span> BaseMovingAverageModelSettings

## Constructor

```python
BaseMovingAverageModelSettings()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> elasticsearch.BaseMovingAverageModelSettings
```

### <span class="badge object-method"></span> model

```python
def model(model: elasticsearch.MovingAverageModel) -> typing.Self
```

### <span class="badge object-method"></span> predict

```python
def predict(predict: str) -> typing.Self
```

### <span class="badge object-method"></span> window

```python
def window(window: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [BaseMovingAverageModelSettings](./object-BaseMovingAverageModelSettings.md)
